import { Externals, BuildPackageOptions, CreateEntryPointOptions } from '../common.types';
declare type CompilePackageArgs = {
    name: string;
    externals: Externals;
    entry: EntryObject;
    debug?: boolean;
    minifier: 'terser' | 'esbuild';
    installPath: string;
};
declare type CompileEntryArgs = {
    name: string;
    externals: Externals;
    entry: any;
    installPath: string;
    measureComposition: boolean;
};
declare type BuildPackageArgs = {
    name: string;
    installPath: string;
    externals: Externals;
    options: BuildPackageOptions;
};
declare type EntryObject = {
    [key: string]: string;
};
declare type CompiledAssetStat = {
    file: string;
    size: number;
};
declare type CompilePackageReturn = {
    assets: CompiledAssetStat[];
};
declare type BuiltAssetStat = {
    name: string;
    type: string;
    size: number;
    gzip: number;
    parse: {
        baseParseTime?: number;
        scriptParseTime?: number;
    } | null;
};
declare type BuildPackageReturn = {
    assets: BuiltAssetStat[];
};
declare class BuildUtils {
    static createEntryPoint(packageName: string, installPath: string, options: CreateEntryPointOptions): string;
    static compileEntry({ entry, externals, installPath, measureComposition, }: CompileEntryArgs): Promise<CompilePackageReturn>;
    static compilePackage({ name, entry, externals, minifier, installPath, }: CompilePackageArgs): Promise<CompilePackageReturn>;
    static buildPackage({ name, installPath, externals, options, }: BuildPackageArgs): Promise<BuildPackageReturn>;
    static buildPackageIgnoringMissingDeps({ name, externals, installPath, options }: BuildPackageArgs, buildIteration: number): Promise<BuildPackageReturn>;
}
export default BuildUtils;
//# sourceMappingURL=build.utils.d.ts.map